==> xmonad-0.18.0-125-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad
version:              0.18.0
visibility:           public
id:                   xmonad-0.18.0-GLF9DtFf0xA137oEkCMUf9
key:                  xmonad-0.18.0-GLF9DtFf0xA137oEkCMUf9
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion, Tony Zorman

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  9ca45b7bdd87679d60bf7b8db6982949
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.18.0-GLF9DtFf0xA137oEkCMUf9
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2 base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    setlocale-1.0.0.10-GC7Qt5v5q5DGkg7CdVa6x5 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.18.0-144-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad
version:              0.18.0
visibility:           public
id:                   xmonad-0.18.0-CW2ThBsG6u778TpJuGrtuP
key:                  xmonad-0.18.0-CW2ThBsG6u778TpJuGrtuP
license:              BSD-3-Clause
maintainer:           xmonad@haskell.org
author:
    Spencer Janssen, Don Stewart, Adam Vogt, David Roundy, Jason Creighton,
    Brent Yorgey, Peter Jones, Peter Simons, Andrea Rossato, Devin Mullins,
    Lukas Mai, Alec Berryman, Stefan O'\''Rear, Daniel Wagner, Peter J. Jones,
    Daniel Schoepe, Karsten Schoelzel, Neil Mitchell, Joachim Breitner,
    Peter De Wachter, Eric Mertens, Geoff Reedy, Michiel Derhaeg,
    Philipp Balzarek, Valery V. Vorotyntsev, Alex Tarkovsky, Fabian Beuke,
    Felix Hirn, Michael Sloan, Tomas Janousek, Vanessa McHale, Nicolas Pouillard,
    Aaron Denney, Austin Seipp, Benno Fünfstück, Brandon S Allbery, Chris Mears,
    Christian Thiemann, Clint Adams, Daniel Neri, David Lazar, Ferenc Wagner,
    Francesco Ariis, Gábor Lipták, Ivan N. Veselov, Ivan Tarasov, Javran Cheng,
    Jens Petersen, Joey Hess, Jonne Ransijn, Josh Holland, Khudyakov Alexey,
    Klaus Weidner, Michael G. Sloan, Mikkel Christiansen, Nicolas Dudebout,
    Ondřej Súkup, Paul Hebble, Shachaf Ben-Kiki, Siim Põder, Tim McIver,
    Trevor Elliott, Wouter Swierstra, Conrad Irwin, Tim Thelion, Tony Zorman

homepage:             http://xmonad.org
synopsis:             A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from the
    keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other extensions,
    may be written by the user in config files. Layouts are applied
    dynamically, and different layouts may be used on each workspace.
    Xinerama is fully supported, allowing windows to be tiled on several
    screens.

category:             System
abi:                  3c26a6173e2fe1f61a5c0359acb81036
exposed:              True
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet

hidden-modules:       Paths_xmonad
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-0.18.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad
hs-libraries:         HSxmonad-0.18.0-CW2ThBsG6u778TpJuGrtuP
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 process-1.6.18.0
    setlocale-1.0.0.10-GC7Qt5v5q5DGkg7CdVa6x5 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html:         /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
